pub trait RotatingAnim:
RotatingRequirement
+ Sized
+ 'static {
// Provided methods
fn rotating(&mut self, angle: f64, axis: DVec3) -> RotatingAnimation<Self>
where Self: Aabb { ... }
fn rotating_at<A: Locate<Self>>(
&mut self,
angle: f64,
axis: DVec3,
anchor: A,
) -> RotatingAnimation<Self> { ... }
}Expand description
The methods to create rotation animations for T that satisfies RotatingRequirement
Provided Methods
Sourcefn rotating(&mut self, angle: f64, axis: DVec3) -> RotatingAnimation<Self>where
Self: Aabb,
fn rotating(&mut self, angle: f64, axis: DVec3) -> RotatingAnimation<Self>where
Self: Aabb,
Rotate by a given angle about a given axis at center.
Sourcefn rotating_at<A: Locate<Self>>(
&mut self,
angle: f64,
axis: DVec3,
anchor: A,
) -> RotatingAnimation<Self>
fn rotating_at<A: Locate<Self>>( &mut self, angle: f64, axis: DVec3, anchor: A, ) -> RotatingAnimation<Self>
Rotate by a given angle about a given axis at the given anchor.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".