RotatingAnim

Trait RotatingAnim 

pub trait RotatingAnim:
    RotatingRequirement
    + Sized
    + 'static {
    // Provided methods
    fn rotating(&mut self, angle: f64, axis: DVec3) -> AnimationCell<Self>
       where Self: Aabb { ... }
    fn rotating_at<A: Locate<Self>>(
        &mut self,
        angle: f64,
        axis: DVec3,
        anchor: A,
    ) -> AnimationCell<Self> { ... }
}
The methods to create rotation animations for T that satisfies RotatingRequirement

Provided Methods

fn rotating(&mut self, angle: f64, axis: DVec3) -> AnimationCell<Self>
where Self: Aabb,

Rotate by a given angle about a given axis at center.

fn rotating_at<A: Locate<Self>>( &mut self, angle: f64, axis: DVec3, anchor: A, ) -> AnimationCell<Self>

Rotate by a given angle about a given axis at the given anchor.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T: RotatingRequirement + 'static> RotatingAnim for T